@@ -228,7 +228,7 @@ class PrintInstanceTypeHelp(argparse.Action):
         print()
         print(fill('A single instance type can be requested to be used by all entry points by providing the instance type name.  Different instance types can also be requested for different entry points of an app or applet by providing a JSON string mapping from function names to instance types, e.g.'))
         print()
-        print('    {"main": "mem2_hdd2_x2", "other_function": "mem2_hdd2_x1"}')
+        print('    {"main": "mem2_hdd2_v2_x2", "other_function": "mem1_ssd1_v2_x2"}')
         if parser.prog == 'dx run':
             print()
             print(fill('If running a workflow, different stages can have different instance type ' +
@@ -238,16 +238,16 @@ class PrintInstanceTypeHelp(argparse.Action):
                        'identifier is provided, the value is applied as a default for all stages.'))
             print()
             print(fill('The following example runs all entry points of the first stage with ' +
-                       'mem2_hdd2_x2, the stage named "BWA" with mem2_hdd2_x1, and all other ' +
-                       'stages with mem2_hdd2_x4'))
+                       'mem2_hdd2_v2_x2, the stage named "BWA" with mem1_ssd1_v2_x2, and all other ' +
+                       'stages with mem2_hdd2_v2_x4'))
             print()
-            print('    Example: dx run workflow --instance-type 0=mem2_hdd2_x2 \\')
-            print('               --instance-type BWA=mem2_hdd2_x1 --instance-type mem2_hdd2_x4')
+            print('    Example: dx run workflow --instance-type 0=mem2_hdd2_v2_x2 \\')
+            print('               --instance-type BWA=mem1_ssd1_v2_x2 --instance-type mem2_hdd2_v2_x4')
         print()
         print('Available instance types:')
         print()
         print(format_table(InstanceTypesCompleter.instance_types.values(),
-                           column_names=InstanceTypesCompleter.instance_types.values()[0]._fields))
+                           column_names=list(InstanceTypesCompleter.instance_types.values())[0]._fields))
         parser.exit(0)
 
 instance_type_arg = argparse.ArgumentParser(add_help=False)
@@ -281,16 +281,21 @@ contains_phi.add_argument('--phi', dest='containsPHI', choices=["true", "false"]
                           help='If set to true, only projects that contain PHI data will be retrieved. ' +
                           'If set to false, only projects that do not contain PHI data will be retrieved.')
 
-def _parse_inst_type(thing):
+def _parse_dictionary_or_string_input(thing, arg_name):
     if thing.strip().startswith('{'):
-        # expects a map of entry point to instance type
+        # expects a map, e.g of entry point to instance type or instance count
         try:
             return json.loads(thing)
         except ValueError:
-            raise DXCLIError("Error while parsing JSON value for --instance-type")
+            raise DXCLIError("Error while parsing JSON value for " + arg_name)
     else:
         return thing
 
+def _parse_inst_type(thing):
+    return _parse_dictionary_or_string_input(thing, "--instance-type")
+
+def _parse_inst_count(thing):
+    return _parse_dictionary_or_string_input(thing, "--instance-count")
 
 def process_instance_type_arg(args, for_workflow=False):
     if args.instance_type:
@@ -312,6 +317,15 @@ def process_instance_type_arg(args, for_workflow=False):
             # is a string
             args.instance_type = _parse_inst_type(args.instance_type)
 
+def process_instance_count_arg(args):
+    if args.instance_count:
+        # If --instance-count was used multiple times, the last one
+        # from the list will override the previous ones
+        if not isinstance(args.instance_count, basestring):
+            args.instance_count = _parse_inst_count(args.instance_count[-1])
+        else:
+            # is a string
+            args.instance_count = _parse_inst_count(args.instance_count)
 
 def get_update_project_args(args):
     input_params = {}
@@ -331,6 +345,10 @@ def get_update_project_args(args):
         input_params["containsPHI"] = True if args.containsPHI == 'true' else False
     if args.bill_to is not None:
         input_params["billTo"] = args.bill_to
+    if args.allowed_executables is not None:
+        input_params['allowedExecutables'] = args.allowed_executables
+    if args.unset_allowed_executables:
+        input_params['allowedExecutables'] = None
     return input_params
 
 
